@@ -10,7 +10,7 @@ from pytest import mark, raises
 
 from wand.image import ClosedImageError, Image
 from wand.color import Color
-from wand.compat import PY3, text, text_type, string_type
+from wand.compat import PY3, string_type, text, text_type
 from wand.exceptions import MissingDelegateError
 from wand.font import Font
 
@@ -908,13 +908,13 @@ def test_set_alpha_channel(fx_asset):
 def test_get_background_color(fx_asset):
     """Gets the background color."""
     with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
-        assert Color('white') == img.background_color
+        assert Color('transparent') == img.background_color
 
 
 def test_set_background_color(fx_asset):
     """Sets the background color."""
     with Image(filename=str(fx_asset.join('croptest.png'))) as img:
-        with Color('transparent') as color:
+        with Color('red') as color:
             img.background_color = color
             assert img.background_color == color
 
@@ -1128,6 +1128,24 @@ def test_setgravity():
         assert img.gravity == 'center'
 
 
+def test_negate_default(display, fx_asset):
+    def test(c1, c2):
+        assert c1.red_int8 + c2.red_int8 == 255 and \
+               c1.green_int8 + c2.green_int8 == 255 and \
+               c1.blue_int8 + c2.blue_int8 == 255
+    with Image(filename=str(fx_asset.join('gray_range.jpg'))) as img:
+        display(img)
+        left_top = img[0, 0]
+        left_bottom = img[0, -1]
+        right_top = img[-1, 0]
+        right_bottom = img[-1, -1]
+        img.negate()
+        test(left_top, img[0, 0])
+        test(left_bottom, img[0, -1])
+        test(right_top, img[-1, 0])
+        test(right_bottom, img[-1, -1])
+
+
 def test_normalize_default(display, fx_asset):
     with Image(filename=str(fx_asset.join('gray_range.jpg'))) as img:
         display(img)
@@ -1233,7 +1251,7 @@ def test_gaussian_blur(fx_asset, display):
         img.gaussian_blur(30, 10)
         after = img[100, 100]
         assert before != after
-        assert 0.84 <= after.red <= 0.85
+        assert 0.84 <= after.red <= 0.851
         assert 0.74 <= after.green <= 0.75
         assert 0.655 <= after.blue < 0.67
 
@@ -1257,7 +1275,12 @@ def test_unsharp_mask(fx_asset, display):
         assert before != after
         assert 0.89 <= after.red <= 0.90
         assert 0.82 <= after.green <= 0.83
-        assert 0.73 <= after.blue < 0.74
+        assert 0.72 <= after.blue < 0.74
+
+
+def test_compression(fx_asset):
+    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+        assert img.compression == 'group4'
 
 
 def test_issue_150(fx_asset, tmpdir):
